@@ -179,7 +179,7 @@ public final class DBTablePrintMIB extends DBTableBase {
 
         DatabaseAccess dataaccess =
             DatabaseAccessPool.getInstance().popQueueDatabaseAccess();
-        ArrayList nodeSNMPPrintList = new ArrayList();
+        ArrayList<PrintMibInfo> nodeSNMPPrintList = new ArrayList<PrintMibInfo>();
 
         try {
             //sql̍쐬
